Steel wheel 5x13" for Peugeot 206 1.1i (10/1998 - 02/2009) - Tyre Leader
Description: Buy your wheels compatible with your 5x13" Peugeot 206 1.1i (10/1998 - 02/2009) on Tyre Leader : Shipping and discount price guaranteed.

- Home page
- Pro
- My account
- 0Cart

Menu

Car tyre

Motorcycle tyre

Quad tyre

Heavy truck tyres

Agricultural tyres

Winter tyre

Steel wheels

Alloy wheels

Package wheels + tyres

Snow chains

Guide

Delivery and fitting

Pro

My account

Home page

Search by vehicle
Click here to make a search
Vehicle brand
Model
Engine type

# Steel wheel Peugeot 206 1.1i
(10/1998 - 02/2009) 5x13"

Recommended retail price | 43.40 £ (-36%)
Price per unit | 27,63£
Quantity

In stock

Free delivery from 72h

Best priceAvaiblable stocksSecure payment

1 Width | 5"
2 Diameter | 13"
Number of bolts | 4
3 Hole circle | 108 mm
4 Offset | 28 mm
5 Center bore | 65 mm

Non contractual pictures

This rim is compatible with the following sizes :

- 165/70R13
- 175/70R13

1 Width | 5"
2 Diameter | 13"
Number of bolts | 4
3 Hole circle | 108 mm
4 Offset | 28 mm
5 Center bore | 65 mm

165/70R13
175/70R13

## Top 10 tyres 165/70R13

| + | + | Hifly WIN-Turi 212 165/70 R13 79T 3PMSF |  | Passenger winter |  | 2 wheels + 2 tyres135,66£Buy
| + | + | Hifly Super 2000 165/70 R13C 88/86S 6PR |  | Light truck summer |  | 2 wheels + 2 tyres143,66£Buy
| + | + | Apollo Amazer 3G Maxx 165/70 R13 79T |  | Passenger summer |  | 2 wheels + 2 tyres122,86£Buy
| + | + | Infinity INF 049 165/70 R13 79T 3PMSF |  | Passenger winter |  | 2 wheels + 2 tyres121,06£Buy
| + | + | Gislaved Urban * Speed 165/70 R13 79T |  | Passenger summer |  | 2 wheels + 2 tyres121,26£Buy
| + | + | Sailun Atrezzo SH402 165/70 R13 79T |  | Passenger summer |  | 2 wheels + 2 tyres120,86£Buy
| + | + | Tristar Ecopower 109 165/70 R13 79T |  | Passenger summer |  | 2 wheels + 2 tyres113,06£Buy
| + | + | Tristar Snowpower 165/70 R13 79T 3PMSF |  | Passenger winter |  | 2 wheels + 2 tyres113,26£Buy
| + | + | Apollo Amazer 3G Maxx 165/70 R13 83T XL |  | Passenger summer |  | 2 wheels + 2 tyres141,66£Buy
| + | + | Goodride H550 A 165/70 R13 79T |  | Passenger summer |  | 2 wheels + 2 tyres120,26£Buy

Click here to view all our tyres 165/70R13

## Top 10 tyres 175/70R13

| + | + | Falken Sincera SN-832 175/70 R13 82T |  | Passenger summer | 183,86 £-39 % | 2 wheels + 2 tyres111,86£Buy
| + | + | Infinity INF 049 175/70 R13 82T 3PMSF |  | Passenger winter |  | 2 wheels + 2 tyres115,46£Buy
| + | + | Event MJ683 175/70 R13 82T |  | Passenger summer |  | 2 wheels + 2 tyres123,66£Buy
| + | + | Uniroyal Rainexpert 175/70 R13 82T | 1 Review | Passenger summer | 193,68 £-34 % | 2 wheels + 2 tyres127,66£Buy
| + | + | Gislaved Urban * Speed 175/70 R13 82T |  | Passenger summer |  | 2 wheels + 2 tyres127,66£Buy
| + | + | Cooper Weathermaster SA2 175/70 R13 82T 3PMSF |  | Passenger winter | 190,24 £-37 % | 2 wheels + 2 tyres120,46£Buy
| + | + | Riken Snowtime B2 175/70 R13 82T 3PMSF |  | Passenger winter | 154,04 £-26 % | 2 wheels + 2 tyres114,26£Buy
| + | + | Meteor Cruiser IS12 175/70 R13 82T |  | Passenger summer |  | 2 wheels + 2 tyres114,26£Buy
| + | + | Hankook Optimo H730 175/70 R13 82T M+S |  | Passenger all season | 176,44 £-27 % | 2 wheels + 2 tyres129,06£Buy
| + | + | Sava Adapto 175/70 R13 82T 3PMSF |  | Passenger all season | 170,40 £-29 % | 2 wheels + 2 tyres121,06£Buy

Click here to view all our tyres 175/70R13